"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const dotenv_1 = __importDefault(require("dotenv"));
const fs_1 = __importDefault(require("fs"));
const os_1 = require("os");
const path_1 = __importDefault(require("path"));
const js_yaml_1 = __importDefault(require("js-yaml"));
exports.setActionEnv = () => {
    const actionSetting = js_yaml_1.default.safeLoad(fs_1.default.readFileSync(path_1.default.resolve(__dirname, '../node_modules/@technote-space/release-github-actions', 'action.yml'), 'utf8')) || {};
    const inputs = 'inputs' in actionSetting && typeof actionSetting['inputs'] === 'object' ? actionSetting['inputs'] : {};
    Object.keys(inputs).filter(key => 'default' in inputs[key]).map(key => ({
        key: `INPUT_${key.replace(/ /g, '_').toUpperCase()}`,
        value: `${inputs[key].default}`,
    })).forEach(env => {
        process.env[env.key] = env.value;
    });
};
exports.setLocalEnv = (name) => {
    if (!fs_1.default.existsSync(path_1.default.resolve(process.cwd(), name))) {
        throw new Error(`${name} file is required.`);
    }
    const config = dotenv_1.default.parse(fs_1.default.readFileSync(path_1.default.resolve(process.cwd(), name)));
    Object.keys(config).forEach(key => process.env[key] = config[key]);
};
exports.setEnv = (name) => {
    var _a;
    exports.setActionEnv();
    exports.setLocalEnv(name);
    if (!process.env['GITHUB_TOKEN']) {
        throw new Error('<GITHUB_TOKEN> is required.');
    }
    if (!process.env['TARGET_OWNER']) {
        throw new Error('<TARGET_OWNER> is required.');
    }
    if (!process.env['TARGET_REPO']) {
        throw new Error('<TARGET_REPO> is required.');
    }
    process.env.INPUT_GITHUB_TOKEN = process.env['GITHUB_TOKEN'];
    process.env.GITHUB_ACTOR = process.env['TARGET_OWNER'];
    // eslint-disable-next-line no-magic-numbers
    process.env.GITHUB_WORKSPACE = (_a = process.env['WORKSPACE'], (_a !== null && _a !== void 0 ? _a : path_1.default.resolve(os_1.tmpdir(), 'release-ga', Math.random().toString(36).slice(-8))));
    delete process.env['GITHUB_TOKEN'];
};
